==> eam-wshub-proxyclient-11.6-0-sources.jar: net/datastream/schemas/mp_fields/CHANGENOTICELINEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CHANGENOTICELINEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CHANGENOTICELINEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CHANGENOTICEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CHANGENOTICELINEID_Type", propOrder = {
    "changenoticeid",
    "line"
})
public class CHANGENOTICELINEID_Type {

    @XmlElement(name = "CHANGENOTICEID", required = true)
    protected CHANGENOTICEID_Type changenoticeid;
    @XmlElement(name = "LINE")
    protected long line;

    /**
     * Obtient la valeur de la propriété changenoticeid.
     * 
     * @return
     *     possible object is
     *     {@link CHANGENOTICEID_Type }
     *     
     */
    public CHANGENOTICEID_Type getCHANGENOTICEID() {
        return changenoticeid;
    }

    /**
     * Définit la valeur de la propriété changenoticeid.
     * 
     * @param value
     *     allowed object is
     *     {@link CHANGENOTICEID_Type }
     *     
     */
    public void setCHANGENOTICEID(CHANGENOTICEID_Type value) {
        this.changenoticeid = value;
    }

    /**
     * Obtient la valeur de la propriété line.
     * 
     */
    public long getLINE() {
        return line;
    }

    /**
     * Définit la valeur de la propriété line.
     * 
     */
    public void setLINE(long value) {
        this.line = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/CHANGENOTICELINEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CHANGENOTICELINEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CHANGENOTICELINEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CHANGENOTICEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CHANGENOTICELINEID_Type", propOrder = {
    "changenoticeid",
    "line"
})
public class CHANGENOTICELINEID_Type {

    @XmlElement(name = "CHANGENOTICEID", required = true)
    protected CHANGENOTICEID_Type changenoticeid;
    @XmlElement(name = "LINE")
    protected long line;

    /**
     * Gets the value of the changenoticeid property.
     * 
     * @return
     *     possible object is
     *     {@link CHANGENOTICEID_Type }
     *     
     */
    public CHANGENOTICEID_Type getCHANGENOTICEID() {
        return changenoticeid;
    }

    /**
     * Sets the value of the changenoticeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CHANGENOTICEID_Type }
     *     
     */
    public void setCHANGENOTICEID(CHANGENOTICEID_Type value) {
        this.changenoticeid = value;
    }

    /**
     * Gets the value of the line property.
     * 
     */
    public long getLINE() {
        return line;
    }

    /**
     * Sets the value of the line property.
     * 
     */
    public void setLINE(long value) {
        this.line = value;
    }

}
